@@ -1,7 +1,7 @@
 from deluge.plugins.init import PluginInitBase
 
 
-VERSION = (0, 1, 6)
+VERSION = (0, 1, 7)
 
 
 class CorePlugin(PluginInitBase):
@@ -18,3 +18,10 @@ class GtkUIPlugin(PluginInitBase):
         from gtkui import GtkUI as _plugin_cls
         self._plugin_cls = _plugin_cls
         super(GtkUIPlugin, self).__init__(plugin_name)
+
+
+class WebUIPlugin(PluginInitBase):
+    def __init__(self, plugin_name):
+        from webui import WebUI as _plugin_cls
+        self._plugin_cls = _plugin_cls
+        super(WebUIPlugin, self).__init__(plugin_name)
